==> ehome-rcm-0.13.10.tgz: package/es/form-view/fields/SingleText/index.js <==
import "antd-mobile/es/modal/style";
import _Modal from "antd-mobile/es/modal";
import "antd-mobile/es/icon/style";
import _Icon from "antd-mobile/es/icon";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';

var SingleText =
/*#__PURE__*/
function (_ref) {
  _inherits(SingleText, _ref);

  function SingleText(props) {
    var _this;

    _classCallCheck(this, SingleText);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(SingleText).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "calcRows", function () {
      var textHeight = _this.hideValue ? _this.hideValue.clientHeight : 0;
      var standardHeight = _this.standardValue ? _this.standardValue.clientHeight : 20;
      var rows = Math.round(textHeight / standardHeight);

      _this.setState({
        rows: rows
      });
    });

    _defineProperty(_assertThisInitialized(_this), "changeCollapse", function () {
      var collapse = _this.state.collapse;

      _this.setState({
        collapse: !collapse
      });
    });

    _defineProperty(_assertThisInitialized(_this), "openModal", function () {
      var scrollTop = document.body.scrollTop || document.documentElement.scrollTop;
      var rootElement = document.getElementById('root');

      if (rootElement) {
        // 使 root 脱离文档流
        rootElement.classList.add('dialog-open'); // 把脱离文档流的 root 拉上去，否则页面会回到顶部！

        rootElement.style.top = "".concat(-scrollTop, "px");
      }

      _this.setState({
        visible: true,
        bodyScrollTop: scrollTop
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closeModal", function (e) {
      e.stopPropagation();
      var bodyScrollTop = _this.state.bodyScrollTop;
      var rootElement = document.getElementById('root');
      if (rootElement) rootElement.classList.remove('dialog-open'); // 滚回到老地方

      document.body.scrollTop = bodyScrollTop;
      document.documentElement.scrollTop = bodyScrollTop;

      _this.setState({
        visible: false
      });
    });

    _this.state = {
      // 是否收起
      collapse: true,
      // 文本内容的行数
      rows: 0,
      visible: false
    };
    return _this;
  }

  _createClass(SingleText, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.calcRows();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var field = this.props.field; // 字段变化后，重新计算文本的行数

      if (field !== prevProps.field) {
        this.calcRows();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      // root回到文档流中
      var rootElement = document.getElementById('root');
      if (rootElement) rootElement.classList.remove('dialog-open');
    } // 计算文本的行数

  }, {
    key: "render",
    value: function render() {
      var _classnames,
          _this2 = this;

      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType;
      var _this$state = this.state,
          rows = _this$state.rows,
          collapse = _this$state.collapse,
          visible = _this$state.visible; // eslint-disable-next-line prefer-const

      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue,
          _field$fieldExtra = field.fieldExtra,
          fieldExtra = _field$fieldExtra === void 0 ? '{}' : _field$fieldExtra;

      var _JSON$parse = JSON.parse(fieldValue),
          text = _JSON$parse.text;

      var _JSON$parse2 = JSON.parse(fieldExtra),
          _JSON$parse2$rules = _JSON$parse2.rules,
          rules = _JSON$parse2$rules === void 0 ? [] : _JSON$parse2$rules;

      var prefixCls = 'eh-field-view-single-text';
      var modalPrefixCls = "".concat(prefixCls, "-modal");
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && !text;
      var textContent = rules.length && rules[0].key === 'tel' && text ? React.createElement("a", {
        className: "".concat(prefixCls, "-tel"),
        href: "tel:".concat(text)
      }, text) : React.createElement("span", null, text || '无'); // 左右结构时，是否需要省略显示

      var horEllipsis = layoutType === 0 && rows > 1; // 上下结构时，是否需要 展开/收起 的开关

      var needCollapseSwitch = layoutType === 1 && rows > 5 && rows <= 10; // 上下结构时，是否显示简略信息

      var verBrief = layoutType === 1 && rows > 10;
      var valueCls = classnames("".concat(commonPrefixCls, "-value ").concat(prefixCls, "-value"), (_classnames = {}, _defineProperty(_classnames, "".concat(prefixCls, "-value-collapse"), needCollapseSwitch && collapse), _defineProperty(_classnames, "".concat(prefixCls, "-value-brief"), verBrief), _classnames));
      return hidden ? null : React.createElement("div", {
        className: prefixCls
      }, React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), React.createElement("div", {
        className: valueCls,
        onClick: horEllipsis || verBrief ? this.openModal : null
      }, React.createElement("div", {
        className: "".concat(prefixCls, "-value-content")
      }, textContent), React.createElement("div", {
        className: "".concat(prefixCls, "-value-hide"),
        ref: function ref(_ref2) {
          _this2.hideValue = _ref2;
        }
      }, textContent), React.createElement("div", {
        className: "".concat(prefixCls, "-value-standard"),
        ref: function ref(_ref3) {
          _this2.standardValue = _ref3;
        }
      }, "\u4E00\u884C\u9AD8\u5EA6\u7684\u6587\u672C")), horEllipsis ? React.createElement("i", {
        className: "".concat(prefixCls, "-icon eh-iconfont"),
        onClick: this.openModal
      }, "\uE773") : null, needCollapseSwitch ? React.createElement("div", {
        className: "".concat(prefixCls, "-collapse-switch")
      }, React.createElement("span", {
        onClick: this.changeCollapse
      }, collapse ? '展开' : '收起')) : null, React.createElement(_Modal, {
        popup: true,
        visible: visible,
        onClose: this.closeModal,
        animationType: "slide-up"
      }, React.createElement("div", {
        className: modalPrefixCls
      }, React.createElement("div", {
        className: "".concat(modalPrefixCls, "-header")
      }, React.createElement(_Icon, {
        type: "cross",
        onClick: this.closeModal
      }), React.createElement("span", {
        className: "".concat(modalPrefixCls, "-header-text")
      }, fieldName)), React.createElement("div", {
        className: "".concat(modalPrefixCls, "-content")
      }, text))));
    }
  }]);

  return SingleText;
}(PureComponent || Component);

SingleText.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
SingleText.defaultProps = {
  field: {}
};
export default SingleText;

==> ehome-rcm-0.15.2.tgz: package/es/form-view/fields/SingleText/index.js <==
import "antd-mobile/es/modal/style";
import _Modal from "antd-mobile/es/modal";
import "antd-mobile/es/icon/style";
import _Icon from "antd-mobile/es/icon";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { return function () { var Super = _getPrototypeOf(Derived), result; if (_isNativeReflectConstruct()) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';

var SingleText = /*#__PURE__*/function (_ref) {
  _inherits(SingleText, _ref);

  var _super = _createSuper(SingleText);

  function SingleText(props) {
    var _this;

    _classCallCheck(this, SingleText);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "calcRows", function () {
      var textHeight = _this.hideValue ? _this.hideValue.clientHeight : 0;
      var standardHeight = _this.standardValue ? _this.standardValue.clientHeight : 20;
      var rows = Math.round(textHeight / standardHeight);

      _this.setState({
        rows: rows
      });
    });

    _defineProperty(_assertThisInitialized(_this), "changeCollapse", function () {
      var collapse = _this.state.collapse;

      _this.setState({
        collapse: !collapse
      });
    });

    _defineProperty(_assertThisInitialized(_this), "openModal", function () {
      var scrollTop = document.body.scrollTop || document.documentElement.scrollTop;
      var rootElement = document.getElementById('root');

      if (rootElement) {
        // 使 root 脱离文档流
        rootElement.classList.add('dialog-open'); // 把脱离文档流的 root 拉上去，否则页面会回到顶部！

        rootElement.style.top = "".concat(-scrollTop, "px");
      }

      _this.setState({
        visible: true,
        bodyScrollTop: scrollTop
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closeModal", function (e) {
      e.stopPropagation();
      var bodyScrollTop = _this.state.bodyScrollTop;
      var rootElement = document.getElementById('root');
      if (rootElement) rootElement.classList.remove('dialog-open'); // 滚回到老地方

      document.body.scrollTop = bodyScrollTop;
      document.documentElement.scrollTop = bodyScrollTop;

      _this.setState({
        visible: false
      });
    });

    _this.state = {
      // 是否收起
      collapse: true,
      // 文本内容的行数
      rows: 0,
      visible: false
    };
    return _this;
  }

  _createClass(SingleText, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.calcRows();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var field = this.props.field; // 字段变化后，重新计算文本的行数

      if (field !== prevProps.field) {
        this.calcRows();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      // root回到文档流中
      var rootElement = document.getElementById('root');
      if (rootElement) rootElement.classList.remove('dialog-open');
    } // 计算文本的行数

  }, {
    key: "render",
    value: function render() {
      var _classnames,
          _this2 = this;

      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType;
      var _this$state = this.state,
          rows = _this$state.rows,
          collapse = _this$state.collapse,
          visible = _this$state.visible; // eslint-disable-next-line prefer-const

      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue,
          _field$fieldExtra = field.fieldExtra,
          fieldExtra = _field$fieldExtra === void 0 ? '{}' : _field$fieldExtra;

      var _JSON$parse = JSON.parse(fieldValue),
          text = _JSON$parse.text;

      var _JSON$parse2 = JSON.parse(fieldExtra),
          _JSON$parse2$rules = _JSON$parse2.rules,
          rules = _JSON$parse2$rules === void 0 ? [] : _JSON$parse2$rules;

      var prefixCls = 'eh-field-view-single-text';
      var modalPrefixCls = "".concat(prefixCls, "-modal");
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && !text;
      var textContent = rules.length && rules[0].key === 'tel' && text ? /*#__PURE__*/React.createElement("a", {
        className: "".concat(prefixCls, "-tel"),
        href: "tel:".concat(text)
      }, text) : /*#__PURE__*/React.createElement("span", null, text || '无'); // 左右结构时，是否需要省略显示

      var horEllipsis = layoutType === 0 && rows > 1; // 上下结构时，是否需要 展开/收起 的开关

      var needCollapseSwitch = layoutType === 1 && rows > 5 && rows <= 10; // 上下结构时，是否显示简略信息

      var verBrief = layoutType === 1 && rows > 10;
      var valueCls = classnames("".concat(commonPrefixCls, "-value ").concat(prefixCls, "-value"), (_classnames = {}, _defineProperty(_classnames, "".concat(prefixCls, "-value-collapse"), needCollapseSwitch && collapse), _defineProperty(_classnames, "".concat(prefixCls, "-value-brief"), verBrief), _classnames));
      return hidden ? null : /*#__PURE__*/React.createElement("div", {
        className: prefixCls
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), /*#__PURE__*/React.createElement("div", {
        className: valueCls,
        onClick: horEllipsis || verBrief ? this.openModal : null
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-value-content")
      }, textContent), /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-value-hide"),
        ref: function ref(_ref2) {
          _this2.hideValue = _ref2;
        }
      }, textContent), /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-value-standard"),
        ref: function ref(_ref3) {
          _this2.standardValue = _ref3;
        }
      }, "\u4E00\u884C\u9AD8\u5EA6\u7684\u6587\u672C")), horEllipsis ? /*#__PURE__*/React.createElement("i", {
        className: "".concat(prefixCls, "-icon eh-iconfont"),
        onClick: this.openModal
      }, "\uE773") : null, needCollapseSwitch ? /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-collapse-switch")
      }, /*#__PURE__*/React.createElement("span", {
        onClick: this.changeCollapse
      }, collapse ? '展开' : '收起')) : null, /*#__PURE__*/React.createElement(_Modal, {
        popup: true,
        visible: visible,
        onClose: this.closeModal,
        animationType: "slide-up"
      }, /*#__PURE__*/React.createElement("div", {
        className: modalPrefixCls
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(modalPrefixCls, "-header")
      }, /*#__PURE__*/React.createElement(_Icon, {
        type: "cross",
        onClick: this.closeModal
      }), /*#__PURE__*/React.createElement("span", {
        className: "".concat(modalPrefixCls, "-header-text")
      }, fieldName)), /*#__PURE__*/React.createElement("div", {
        className: "".concat(modalPrefixCls, "-content")
      }, text))));
    }
  }]);

  return SingleText;
}(PureComponent || Component);

SingleText.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
SingleText.defaultProps = {
  field: {}
};
export default SingleText;
